from typing import List, Optional

from sqlalchemy.orm import Session

from app.crud.base import CRUDBase
from app.models.todo import Todo
from app.schemas.todo import TodoCreate, TodoUpdate


class CRUDTodo(CRUDBase[Todo, TodoCreate, TodoUpdate]):
    def get_multi_by_completion(
        self, db: Session, *, completed: bool, skip: int = 0, limit: int = 100
    ) -> List[Todo]:
        return (
            db.query(self.model)
            .filter(Todo.completed == completed)
            .offset(skip)
            .limit(limit)
            .all()
        )


todo = CRUDTodo(Todo)